package net.sf.uctool.mojo;

import java.io.File;
import java.util.ArrayList;

import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.plugin.dependency.fromConfiguration.ArtifactItem;
import org.apache.maven.plugin.dependency.fromConfiguration.UnpackMojo;
import org.codehaus.plexus.archiver.manager.ArchiverManager;

/**
 * Extract HTML resources (images, css, etc.) from uctool dependency.
 * 
 * @goal extract-resources
 * @phase generate-resources
 */
public class ResourcesMojo extends AbstractMojo {

	/**
	 * The output directory. The HTML use case documentation is generated there.
	 * 
	 * @parameter default-value="${project.build.directory}/site/ucs/"
	 * @required
	 */
	private File outputDirectory;

	/**
	 * The version of uctool from which to extract the HTML resources.
	 * 
	 * @parameter default-value="${uctool.version}"
	 * @required
	 */
	private String uctoolVersion;

	/**
	 * Directory to store flag files after unpack
	 * 
	 * @parameter 
	 *            expression="${project.build.directory}/dependency-maven-plugin-markers"
	 */
	private File markersDirectory;

	/**
	 * Used to look up Artifacts in the remote repository.
	 * 
	 * @component
	 */
	private org.apache.maven.artifact.factory.ArtifactFactory factory;

	/**
	 * Used to look up Artifacts in the remote repository.
	 * 
	 * @component
	 */
	private org.apache.maven.artifact.resolver.ArtifactResolver resolver;

	/**
	 * Location of the local repository.
	 * 
	 * @parameter expression="${localRepository}"
	 * @readonly
	 * @required
	 */
	private org.apache.maven.artifact.repository.ArtifactRepository local;

	/**
	 * List of Remote Repositories used by the resolver
	 * 
	 * @parameter expression="${project.remoteArtifactRepositories}"
	 * @readonly
	 * @required
	 */
	private java.util.List remoteRepos;

	/**
	 * To look up Archiver/UnArchiver implementations
	 * 
	 * @component
	 */
	private ArchiverManager archiverManager;

	public void execute() throws MojoExecutionException, MojoFailureException {
		UnpackMojo mojo = new UnpackMojo();
		mojo.setOutputDirectory(outputDirectory);
		ArrayList artifactItems = new ArrayList();
		ArtifactItem item = new ArtifactItem();
		item.setGroupId("net.sf.uctool");
		item.setArtifactId("uctool");
		item.setVersion(uctoolVersion);
		artifactItems.add(item);
		mojo.setArtifactItems(artifactItems);
		mojo.setIncludes("resources/**");

		mojo.setMarkersDirectory(markersDirectory);

		mojo.setFactory(factory);
		mojo.setResolver(resolver);
		mojo.setLocal(local);
		mojo.setRemoteRepos(remoteRepos);
		mojo.setArchiverManager(archiverManager);
		mojo.setLog(getLog());

		mojo.execute();
	}

}
